==> dfiletools-0.4.1.tgz: dfiletools/dfile_unique/dfile_unique.h <==
/* Copyright (C) 2009 Keith Crane

This file is part DFILE Tools.

DFILE Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

DFILE Tools is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with DFILE Tools; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>. */

/*
**  $Id: dfile_unique.h,v 1.2 2009/10/16 20:26:12 keith Exp $
**
**  $Log: dfile_unique.h,v $
**  Revision 1.2  2009/10/16 20:26:12  keith
**  Added GPL to source code.
**
**  Revision 1.1  2009/03/13 01:24:22  keith
**  Initial revision
**
*/

int get_args( int, char * const [], const char **, const char **, int *, int *, dfile_tag_t **, unsigned short *, const char **, const char **, char ** );

int open_dfile( dfile_t **, const char *, dfile_tag_t *, unsigned short, int, char );

void copy_record_to_bind( dfile_bind_t *, field_t *, const unsigned short *, unsigned short );

int process_file( dfile_t *, dfile_t *, dfile_bind_t **, unsigned short, unsigned short *, void *, void * );

int output_record( dfile_t *, void * );

int compile_filters( void **, void **, const char *, const char *, dfile_t *, dfile_t * );

int parse_unique_key( const char ***, unsigned short *, char * );

void assign_field_key( field_t **, field_t *, dfile_bind_t **, unsigned short, dfile_bind_t * );

int compare_field_bind( const field_t **, const dfile_bind_t **, unsigned short );

int copy_record( field_t **, size_t *, const dfile_bind_t *, unsigned short );

==> dfiletools-0.5.1.tgz: dfiletools/dfile_unique/dfile_unique.h <==
/* Copyright (C) 2009, 2010, 2011 Keith Crane

This file is part DFILE Tools.

DFILE Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

DFILE Tools is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with DFILE Tools; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>. */


int get_args( int, char * const [], const char **, const char **, int *, int *, dfile_tag_t **, unsigned short *, const char **, const char **, char ** );

int open_dfile( dfile_t **, const char *, dfile_tag_t *, unsigned short, int, char );

void copy_record_to_bind( dfile_bind_t *, field_t *, const unsigned short *, unsigned short );

int process_file( dfile_t *, dfile_t *, dfile_bind_t **, unsigned short, unsigned short *, void *, void * );

int output_record( dfile_t *, void * );

int compile_filters( void **, void **, const char *, const char *, dfile_t *, dfile_t * );

int parse_unique_key( char ***, unsigned short *, char * );

void assign_field_key( field_t **, field_t *, dfile_bind_t **, unsigned short, dfile_bind_t * );

int compare_field_bind( const field_t **, const dfile_bind_t **, unsigned short );

int copy_record( field_t **, size_t *, const dfile_bind_t *, unsigned short );
